@@ -17,13 +17,13 @@
  *
  *********************************************************************/
 
+#include <sbuild/sbuild-log.h>
+
 #include <cstdlib>
 
 #include <cppunit/ui/text/TestRunner.h>
 #include <cppunit/extensions/TestFactoryRegistry.h>
 
-#include <schroot/sbuild-log.h>
-
 using namespace CppUnit;
 
 int
